Package                                  Version
---------------------------------------- ---------------
aiohappyeyeballs                         2.6.1
aiohttp                                  3.12.15
aiosignal                                1.4.0
annotated-types                          0.7.0
astroid                                  3.1.0
attrs                                    25.3.0
black                                    24.4.2
certifi                                  2025.8.3
cffi                                     2.0.0
charset-normalizer                       3.4.3
click                                    8.2.1
confluent-kafka                          2.5.0
cryptography                             45.0.7
deprecated                               1.2.18
dill                                     0.4.0
flake8                                   7.0.0
frozenlist                               1.7.0
googleapis-common-protos                 1.70.0
grpcio                                   1.74.0
idna                                     3.10
importlib-metadata                       7.1.0
isort                                    5.13.2
loguru                                   0.7.3
mccabe                                   0.7.0
multidict                                6.6.4
mypy                                     1.9.0
mypy-extensions                          1.1.0
opencensus-proto                         0.1.0
opentelemetry-api                        1.25.0
opentelemetry-exporter-opencensus        0.46b0
opentelemetry-exporter-otlp              1.25.0
opentelemetry-exporter-otlp-proto-common 1.25.0
opentelemetry-exporter-otlp-proto-grpc   1.25.0
opentelemetry-exporter-otlp-proto-http   1.25.0
opentelemetry-proto                      1.25.0
opentelemetry-sdk                        1.25.0
opentelemetry-semantic-conventions       0.46b0
packaging                                25.0
pathspec                                 0.12.1
platformdirs                             4.4.0
propcache                                0.3.2
protobuf                                 3.20.3
pycodestyle                              2.11.1
pycparser                                2.23
pydantic                                 2.11.7
pydantic-core                            2.33.2
pydantic-settings                        2.10.1
pyflakes                                 3.2.0
pylint                                   3.1.0
pymysql                                  1.1.1
python-dotenv                            1.1.1
redis                                    3.5.3
redis-py-cluster                         2.1.3
requests                                 2.32.5
setuptools                               80.9.0
sqlalchemy                               2.0.43
sqlmodel                                 0.0.19
toml                                     0.10.2
tomlkit                                  0.13.3
types-cffi                               1.17.0.20250822
types-pyopenssl                          24.1.0.20240722
types-redis                              4.6.0.20241004
types-requests                           2.32.4.20250913
types-setuptools                         80.9.0.20250822
types-toml                               0.10.8.20240310
typing-extensions                        4.15.0
typing-inspection                        0.4.1
urllib3                                  2.5.0
wrapt                                    1.17.3
yarl                                     1.20.1
zipp                                     3.23.0